@@ -24,87 +24,84 @@ use warnings;
 require Exporter;
 
 use vars qw(@ISA @EXPORT $AUTOLOAD);
-@ISA = qw(Locale::Po4a::TransTractor);
-@EXPORT = qw(); # new process write read writepo readpo);
+@ISA    = qw(Locale::Po4a::TransTractor);
+@EXPORT = qw();                             # new process write read writepo readpo);
 
-my $debug=0;
+my $debug = 0;
 
-sub initialize {}
+sub initialize { }
 
 sub parse {
-    my $self=shift;
-    my ($line,$ref);
-    my $paragraph=""; # Buffer where we put the paragraph while building
-    my ($status)=0; # Syntax of KH is:
-                    #   description<nl>variable<nl>help text<nl><nl>
-                    # Status will be:
-                    #   0             1            2        3   0
+    my $self = shift;
+    my ( $line, $ref );
+    my $paragraph = "";                     # Buffer where we put the paragraph while building
+    my ($status)  = 0;                      # Syntax of KH is:
+                                            #   description<nl>variable<nl>help text<nl><nl>
+                                            # Status will be:
+                                            #   0             1            2        3   0
 
-    my ($desc,$variable);
+    my ( $desc, $variable );
 
   LINE:
-    ($line,$ref)=$self->shiftline();
+    ( $line, $ref ) = $self->shiftline();
 
-    while (defined($line)) {
+    while ( defined($line) ) {
         chomp($line);
         print STDERR "status=$status;Seen >>$line<<:" if $debug;
 
-        if ($line =~ /^\#/) {
+        if ( $line =~ /^\#/ ) {
             print STDERR "comment.\n" if $debug;
             $self->pushline("$line\n");
-        } elsif ($status == 0) {
-            if ($line =~ /\S/) {
+        } elsif ( $status == 0 ) {
+            if ( $line =~ /\S/ ) {
                 print STDERR "short desc.\n" if $debug;
-                $desc=$line;
-                $status ++;
+                $desc = $line;
+                $status++;
             } else {
                 print STDERR "empty line.\n" if $debug;
                 $self->pushline("$line\n");
             }
-        } elsif ($status == 1) {
+        } elsif ( $status == 1 ) {
             print STDERR "var name.\n" if $debug;
-            $variable=$line;
+            $variable = $line;
             $status++;
 
-            $self->pushline($self->translate($desc,$ref,"desc_$variable").
-                            "\n$variable\n");
+            $self->pushline( $self->translate( $desc, $ref, "desc_$variable" ) . "\n$variable\n" );
 
-        } elsif ($status == 2) {
+        } elsif ( $status == 2 ) {
             $line =~ s/^  //;
-            if ($line =~ /\S/) {
+            if ( $line =~ /\S/ ) {
                 print STDERR "paragraph line.\n" if $debug;
-                $paragraph .= $line."\n";
+                $paragraph .= $line . "\n";
             } else {
                 print STDERR "end of paragraph.\n" if $debug;
                 $status++;
-                $paragraph=$self->translate($paragraph,
-                                            $ref,
-                                            "helptxt_$variable");
+                $paragraph = $self->translate( $paragraph, $ref, "helptxt_$variable" );
                 $paragraph =~ s/^/  /gm;
                 $self->pushline("$paragraph\n");
-                $paragraph ="";
+                $paragraph = "";
             }
-        } elsif ($status == 3) {
-            if ($line =~ s/^  //) {
-                if ($line =~ /\S/) {
+        } elsif ( $status == 3 ) {
+            if ( $line =~ s/^  // ) {
+                if ( $line =~ /\S/ ) {
                     print "begin of paragraph.\n" if $debug;
-                    $paragraph = $line."\n";
+                    $paragraph = $line . "\n";
                     $status--;
                 } else {
                     print "end of config option.\n" if $debug;
-                    $status=0;
+                    $status = 0;
                     $self->pushline("\n");
                 }
             } else {
-                $self->unshiftline($line,$ref);
-                $status=0;
+                $self->unshiftline( $line, $ref );
+                $status = 0;
             }
         } else {
-            die wrap_ref_mod($ref, "po4a::kernelhelp", gettext("Syntax error"));
+            die wrap_ref_mod( $ref, "po4a::kernelhelp", gettext("Syntax error") );
         }
 
         # Reinit the loop
-        ($line,$ref)=$self->shiftline();
+        ( $line, $ref ) = $self->shiftline();
     }
 }
 
